#
# spec file for package quilter
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           quilter
Version:        2.2.4
Release:        lp152.1.2
Summary:        Writing application
License:        GPL-3.0-only
Group:          Productivity/Office/Word Processor
URL:            https://github.com/lainsce/quilter
Source:         https://github.com/lainsce/quilter/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  libmarkdown-devel
BuildRequires:  meson >= 0.40.0
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  vala
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(granite) >= 5.2.3
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtksourceview-3.0)
BuildRequires:  pkgconfig(gtkspell3-3.0)
BuildRequires:  pkgconfig(webkit2gtk-4.0)
Recommends:     %{name}-lang

%description
A fullscreen word processor for Elementary OS.

%lang_package

%prep
%setup -q

# use default font
sed -i '/QuiltMono.ttf/d' $(grep -rl QuiltMono.ttf)
sed -i '/QuiltVier.ttf/d' $(grep -rl QuiltVier.ttf)

%build
%meson
%meson_build

%install
%meson_install
%suse_update_desktop_file -r com.github.lainsce.quilter GTK Utility TimeUtility
%find_lang com.github.lainsce.quilter %{name}.lang
%fdupes %{buildroot}/%{_datadir}

# dirlist HiDPI icons (see: hicolor/index.theme)
_dirlist=$PWD/dir.lst
pushd %{buildroot}
find ./ | while read _list; do
    echo $_list | grep '[0-9]\@[0-9]' || continue
    _path=$(echo $_list | sed 's/[^/]//')
    if ! ls ${_path%/*}; then
        grep -xqs "\%dir\ ${_path%/*}" $_dirlist || echo "%dir ${_path%/*}" >> $_dirlist
    fi
done
popd

%files -f dir.lst
%license LICENSE
%doc AUTHORS README.md
%{_bindir}/com.github.lainsce.quilter
%{_datadir}/com.github.lainsce.quilter/
%{_datadir}/applications/com.github.lainsce.quilter.desktop
%{_datadir}/glib-2.0/schemas/com.github.lainsce.quilter.gschema.xml
%{_datadir}/gtksourceview-3.0/styles/*.xml
%{_datadir}/icons/hicolor/*/apps/com.github.lainsce.quilter.??g
%{_datadir}/metainfo/com.github.lainsce.quilter.appdata.xml

%files lang -f %{name}.lang

%changelog
* Thu Apr 30 2020 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.2.4:
  * Added language Esperanto (eo) (#333)
  * 2.2.3 - Some varied small changes
* Mon Apr  6 2020 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.2.2:
  * 2.2.1 - General small fixes
* Sat Mar 28 2020 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.2.0:
  * 2.1.3 - Minor css fixes
  * 2.1.3 - Can move window in Focus Mode with right-click and
    hold on Exit Focus Mode button
  * 2.1.3 - Small fix
  * 2.1.3 - Small css style fixes
  * 2.1.3 - Remove Moon Mode
    quilter.changes quilter.spec
* Wed Mar 11 2020 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.1.2:
  * Merge branch 'master' of https://github.com/lainsce/quilter
    quilter.changes quilter.spec
* Wed Feb 19 2020 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.1.1:
  * Fixed: Would duplicate files when open in the sidebar
  * Fixed: If the sidebar was empty and Quilter was reopened, last
    file contents would still appear
* Sun Feb  2 2020 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.1.0:
  * Glib.Settings Move (#310)
  * add new .POT file
  * small change, last thing of 2019 (Vacation Mode for Me)
  * preview font chooser always shown
* Mon Dec 23 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.0.5:
  * 2.0.6 - Add LaTeX support finally
  * 2.0.4 - Sync edit view scroll to preview scroll
  * 2.0.4 - Quilt Vier
  * 2.0.4 - Start work on syncing panes in half-width mode
  * 2.0.4 - Don't remember open files if history setting is off
  * 2.0.4 - Fix outline pane
  * 2.0.4 - Some more fixes and additions
  * Merge pull request #304 from michalzkosmosu/master
  * Merge pull request #302 from NathanBnm/update-fr
  * Merge pull request #301 from NathanBnm/editorconfig
  * .editorconfig with elementary recommended config
  * 2.0.4 - Change tooltip on search icon // Add tooltip on
    replace button
  * Merge pull request #299 from michalzkosmosu/master
  * - follow up fixes
  * - fix weird text in sidebar file boxes
  * Merge pull request #292 from meisenzahl/master
* Mon Nov  4 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.0.3:
  * Update com.github.lainsce.quilter.appdata.xml.in
  * 2.0.2 - Many fixes of issues on this release
* Tue Oct  1 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.0.1:
  * small fix for maximize problems
* Mon Sep  2 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.0.0:
  * Added: New Layout; Half-Width, check it out by changing layouts
    on the statusbar.
* Wed Aug  7 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.9.5:
  * Update com.github.lainsce.quilter.appdata.xml.in
  * 1.9.3 - fix most bugs
  * Merge pull request #271 from bleakgrey/master
  * Don't open cache folder as document
  * Merge pull request #270 from Vistaus/master
  * Save files when creating new document
  * Treat new documents as unique
  * Save files if changed from the sidebar to another file.
  * Merge pull request #265 from NathanBnm/master
* Thu Jul  4 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.9.2:
  * Added: "Remove All Files" button on the sidebar, this way,
    no files will be harmed with the old close file buttons.
  * Some other minor fixes.
* Tue Jun 11 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.9.1:
  * Merge pull request #258 from tim77/master
  * Merge branch 'master' of https://github.com/lainsce/quilter
  * Fix exporting as pdf visual glitches
  * Add Fedora installation instructions
* Mon Jun  3 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.9.0:
  * fix flatpak
  * 1.8.7 - Fix local image syntax with  instead of
  * 1.8.6 - Even more tiny fixes on the Sidebar
  * Update com.github.lainsce.quilter.appdata.xml.in
* Tue May 28 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.8.5:
  * Create FUNDING.yml
* Mon Apr 29 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.8.4:
  * Fixed: cache was not being made, resulting in multiple file loss
    afterwards with many operations.
* Mon Apr 22 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.8.3:
  * cleanup of releases in appdata
  * small fix
* Mon Apr  1 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.8.2:
  * lots of minor fixes
* Mon Mar 25 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.8.1:
  * Update com.github.lainsce.quilter.appdata.xml
  * Finish Files Outline pane
  * new screenshots
  * Merge pull request #233 from lainsce/sidebar-outline
* Mon Mar 18 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.7.6:
  * Merge pull request #229 from Vistaus/master
* Mon Mar 11 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.7.5:
  * small cleaning
  * small improvements all around
  * Merge pull request #225 from donadigo/remove-globals
* Mon Feb 25 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.7.3:
  * Redesign the sidebar so it gets easier to maintain in the
    backend
  * Try to do fixes in file management, only thing remaining is
    to select files if on sidebar otherwise add them to sidebar
  * Don't add duplicate entries on sidebar and be smart
    and confirm clean sidebar.
  * Just some fixes
  * PATCH #9 - Fix how New File button behaves and clean classes
  * PATCH #8 - Fixe New File button, and remove all traces of
    LaTeX, and also add a tab for extension in Preferences
  * PATCH #7 - Add support for opening outside of Quilter many
    files at once
  * PATCH #6 - Fix the clear sidebar button, simplify open I/O
    methods, simplify new file I/O method.
  * PATCH #5 - Edit View now smartly detects indentation while
    typing
  * PATCH #4 - Preview View now shows html from Edit view if
    present
  * PATCH #3 - FileManager is now all rewritten, statusbar
    word/line/char count works properly, and the sidebar now saves
    files properly to their own file.
  * PATCH #2 - Proper selection of files in the sidebar when
    opened on Quilter
* Mon Oct 22 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.6.8:
  * Finally the Sidebar!
  * Some radiobuttons for choices of font & tracking type.
* Mon Sep 24 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.6.6:
  * All text passes a contrast check to be readable now.
* Mon Sep 17 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.6.5:
  * Track words, chars or lines.
  * meson: cleanup post_install script
  * meson: drop lib prefix for libmarkdown
  * CLI option to start with view page shown
  * Fix: view page did not show on start
* Sat Aug 18 2018 avvissu@yandex.by
- Update to 1.6.3:
  * GResource the custom icons
  * Update com.github.lainsce.quilter.appdata.xml
* Wed Aug  1 2018 avvissu@yandex.by
- Update to 1.6.1:
  * Some file changes
  * Add search jump buttons
  * Finalize searchbar things
  * Highlight searches, but it gets gaudy in dark mode
  * Update README.md
  * remove stray spaces
  * Restore this file
  * fix this dependency wrecking havoc
  * Update email
  * Add ja to LINGUAS
  * Clean it all up, and show unicode finally
  * Typerwriter scrolling support for empty document
  * Use default value from SourceView widget when resetting margin
  * Add bottom margin when Typewriter Scrolling Enabled
- Switch to metainfo from appdata
- Remove obsolete macros
* Tue May  8 2018 avvissu@yandex.by
- Update to 1.5.6:
  * fix even more stuff on LaTeX support.
  * LaTeX math support!
  * Update LINGUAS
* Sat Apr 28 2018 avvissu@yandex.by
- Update to 1.5.5:
  * fix maximize/fullscreen problem
  * Update README.md
* Sun Mar 25 2018 badshah400@gmail.com
- Update to version 1.5.4:
  * Fix appdata.
- Changes from version 1.5.3:
  * Preview Mode won't load rogue Javascript code.
  * Preview Mode will also not autojump to the start of the scroll
    at any time.
  * Header becomes Heading in the Cheatsheet.
  * Fixed the Unsaved changes dialog still killing files when
    pressing the New File button.
  * Updated translations.
- Only run post[un] scripts for openSUSE < 1500; for later
  versions rpm file triggers take care of these already.
* Fri Feb 23 2018 avvissu@yandex.by
- Update to 1.5.2:
  * The Headerbar respects the global theme
* Fri Feb 16 2018 avvissu@yandex.by
- Update to 1.5.1:
  * - Fix for AppCenter
  * 1.5.0 - Fix the New File button to not nuke old files
* Tue Jan 30 2018 avvissu@yandex.by
- Update to 1.4.8:
  * Autosave works properly / Fixed Focus Mode highlight
    preferences
  * change screenshot in readme
* Sat Jan 20 2018 avvissu@yandex.by
- Update to 1.4.6:
  * 1.4.5 - update metadata files
  * 1.4.5- even more flatpak friendly
  * 1.4.5 - Focus only current sentence (PR #116 from wyhasany)
  * Add focus type configuration option in Preferences window
  * Focus only current sentence
* Sat Jan  6 2018 avvissu@yandex.by
- Update to 1.4.4:
  * Remove XML comment here
  * Fix the highlight styling and minor annoyances with the
    preview mode
  * Serve highlight.js from local directory
  * Add highlight.js for code block syntax highlighting
  * Update README.md
* Tue Dec 26 2017 jengelh@inai.de
- Remove filler wording from description.
* Tue Nov 21 2017 avvissu@yandex.by
- Update to 1.4.3:
  * restore COPYING file
  * amp up the text in Light Mode's toolbar
  * enable extra goodies in the Preview mode (initial commit)
  * reduce custom styling // add travis badge on main readme
  * small changes
* Tue Nov  7 2017 avvissu@yandex.by
- Initial package
